@@ -9,17 +9,11 @@ def calculate_scores(tp: int, fp: int, fn: int) -> tuple:
     """
     This function calculates the precision,recall and f1_score.
     """
-    try:
-        precision = round(tp / (tp + fp), 2)
-    except ZeroDivisionError:
-        precision = 0
-    try:
-        recall = round(tp / (tp + fn), 2)
-    except ZeroDivisionError:
-        recall = 0
-    try:
-        f1_score = round(2 * (precision * recall) / (precision + recall), 2)
-    except ZeroDivisionError:
-        f1_score = 0
+    precision = (tp + fp) and round(tp / (tp + fp), 2)
+
+    recall = (tp + fn) and round(tp / (tp + fn), 2)
+
+    f1_score = (precision + recall) and round(2 * (precision * recall) / (precision + recall), 2)
+
     return precision, recall, f1_score
 
